@@ -701,30 +701,6 @@ describe("Reducers", () => {
       });
       assert.isFalse(state.waitingForSpoc);
     });
-    it("should have undefined for initial isUserLoggedIn state", () => {
-      assert.isNull(Pocket(undefined, { type: "some_action" }).isUserLoggedIn);
-    });
-    it("should set isUserLoggedIn to false on a POCKET_LOGGED_IN with null", () => {
-      const state = Pocket(undefined, {
-        type: at.POCKET_LOGGED_IN,
-        data: null,
-      });
-      assert.isFalse(state.isUserLoggedIn);
-    });
-    it("should set isUserLoggedIn to false on a POCKET_LOGGED_IN with false", () => {
-      const state = Pocket(undefined, {
-        type: at.POCKET_LOGGED_IN,
-        data: false,
-      });
-      assert.isFalse(state.isUserLoggedIn);
-    });
-    it("should set isUserLoggedIn to true on a POCKET_LOGGED_IN with true", () => {
-      const state = Pocket(undefined, {
-        type: at.POCKET_LOGGED_IN,
-        data: true,
-      });
-      assert.isTrue(state.isUserLoggedIn);
-    });
     it("should set pocketCta with correct object on a POCKET_CTA", () => {
       const data = {
         cta_button: "cta button",
@@ -769,18 +745,6 @@ describe("Reducers", () => {
         INITIAL_STATE.DiscoveryStream
       );
     });
-    it("should set isPrivacyInfoModalVisible to true with SHOW_PRIVACY_INFO", () => {
-      const state = DiscoveryStream(undefined, {
-        type: at.SHOW_PRIVACY_INFO,
-      });
-      assert.equal(state.isPrivacyInfoModalVisible, true);
-    });
-    it("should set isPrivacyInfoModalVisible to false with HIDE_PRIVACY_INFO", () => {
-      const state = DiscoveryStream(undefined, {
-        type: at.HIDE_PRIVACY_INFO,
-      });
-      assert.equal(state.isPrivacyInfoModalVisible, false);
-    });
     it("should set layout data with DISCOVERY_STREAM_LAYOUT_UPDATE", () => {
       const state = DiscoveryStream(undefined, {
         type: at.DISCOVERY_STREAM_LAYOUT_UPDATE,
@@ -822,27 +786,6 @@ describe("Reducers", () => {
       });
       assert.deepEqual(state.config, { enabled: true });
     });
-    it("should set recentSavesEnabled with DISCOVERY_STREAM_PREFS_SETUP", () => {
-      const state = DiscoveryStream(undefined, {
-        type: at.DISCOVERY_STREAM_PREFS_SETUP,
-        data: { recentSavesEnabled: true },
-      });
-      assert.isTrue(state.recentSavesEnabled);
-    });
-    it("should set recentSavesData with DISCOVERY_STREAM_RECENT_SAVES", () => {
-      const state = DiscoveryStream(undefined, {
-        type: at.DISCOVERY_STREAM_RECENT_SAVES,
-        data: { recentSaves: [1, 2, 3] },
-      });
-      assert.deepEqual(state.recentSavesData, [1, 2, 3]);
-    });
-    it("should set isUserLoggedIn with DISCOVERY_STREAM_POCKET_STATE_SET", () => {
-      const state = DiscoveryStream(undefined, {
-        type: at.DISCOVERY_STREAM_POCKET_STATE_SET,
-        data: { isUserLoggedIn: true },
-      });
-      assert.isTrue(state.isUserLoggedIn);
-    });
     it("should set feeds as loaded with DISCOVERY_STREAM_FEEDS_UPDATE", () => {
       const state = DiscoveryStream(undefined, {
         type: at.DISCOVERY_STREAM_FEEDS_UPDATE,
@@ -1199,18 +1142,6 @@ describe("Reducers", () => {
           .bookmarkTitle
       );
     });
-    describe("PREF_CHANGED", () => {
-      it("should set isCollectionDismissible", () => {
-        const state = DiscoveryStream(undefined, {
-          type: at.PREF_CHANGED,
-          data: {
-            name: "discoverystream.isCollectionDismissible",
-            value: true,
-          },
-        });
-        assert.equal(state.isCollectionDismissible, true);
-      });
-    });
   });
   describe("Search", () => {
     it("should return INITIAL_STATE by default", () => {
